@@ -1,7 +1,10 @@
+import io
 import os
 import re
+from unittest.mock import mock_open, patch
 
 import tox
+from ruamel.yaml import YAML
 from tox.venv import VirtualEnv
 
 from tox_conda.env_activator import PopenInActivatedEnv
@@ -273,8 +276,11 @@ def test_conda_env(tmpdir, newconfig, mocksession):
     venv, action, pcalls = create_test_env(config, mocksession, "py123")
     assert venv.envconfig.conda_env
 
-    with mocksession.newaction(venv.name, "getenv") as action:
-        tox_testenv_create(action=action, venv=venv)
+    mock_file = mock_open()
+    with patch("tox_conda.plugin.tempfile.NamedTemporaryFile", mock_file):
+        with mocksession.newaction(venv.name, "getenv") as action:
+            tox_testenv_create(action=action, venv=venv)
+
     pcalls = mocksession._pcalls
     assert len(pcalls) >= 1
     call = pcalls[-1]
@@ -283,7 +289,13 @@ def test_conda_env(tmpdir, newconfig, mocksession):
     assert cmd[1:4] == ["env", "create", "-p"]
     assert venv.path == call.args[4]
     assert call.args[5].startswith("--file")
-    assert call.args[6].endswith("conda-env.yml")
+    assert cmd[6] == str(mock_file().name)
+
+    mock_file.assert_any_call(suffix=".yaml")
+
+    yaml = YAML()
+    tmp_env = yaml.load(mock_open_to_string(mock_file))
+    assert tmp_env["dependencies"][-1].startswith("python=")
 
 
 def test_conda_env_and_spec(tmpdir, newconfig, mocksession):
@@ -321,8 +333,11 @@ def test_conda_env_and_spec(tmpdir, newconfig, mocksession):
     assert venv.envconfig.conda_env
     assert venv.envconfig.conda_spec
 
-    with mocksession.newaction(venv.name, "getenv") as action:
-        tox_testenv_create(action=action, venv=venv)
+    mock_file = mock_open()
+    with patch("tox_conda.plugin.tempfile.NamedTemporaryFile", mock_file):
+        with mocksession.newaction(venv.name, "getenv") as action:
+            tox_testenv_create(action=action, venv=venv)
+
     pcalls = mocksession._pcalls
     assert len(pcalls) >= 1
     call = pcalls[-1]
@@ -331,7 +346,13 @@ def test_conda_env_and_spec(tmpdir, newconfig, mocksession):
     assert cmd[1:4] == ["env", "create", "-p"]
     assert venv.path == call.args[4]
     assert call.args[5].startswith("--file")
-    assert call.args[6].endswith("conda-env.yml")
+    assert cmd[6] == str(mock_file().name)
+
+    mock_file.assert_any_call(suffix=".yaml")
+
+    yaml = YAML()
+    tmp_env = yaml.load(mock_open_to_string(mock_file))
+    assert tmp_env["dependencies"][-1].startswith("python=")
 
     with mocksession.newaction(venv.name, "getenv") as action:
         tox_testenv_install_deps(action=action, venv=venv)
@@ -396,3 +417,38 @@ def test_conda_create_args(newconfig, mocksession):
     assert venv.path == call.args[4]
     assert call.args[5] == "--override-channels"
     assert call.args[6].startswith("python=")
+
+
+def test_verbosity(newconfig, mocksession):
+    config = newconfig(
+        [],
+        """
+        [testenv:py1]
+        conda_deps=numpy
+        [testenv:py2]
+        conda_deps=numpy
+    """,
+    )
+
+    venv, action, pcalls = create_test_env(config, mocksession, "py1")
+    tox_testenv_install_deps(action=action, venv=venv)
+    assert len(pcalls) == 1
+    call = pcalls[0]
+    assert "conda" in call.args[0]
+    assert "install" == call.args[1]
+    assert isinstance(call.stdout, io.IOBase)
+
+    tox.reporter.update_default_reporter(
+        tox.reporter.Verbosity.DEFAULT, tox.reporter.Verbosity.DEBUG
+    )
+    venv, action, pcalls = create_test_env(config, mocksession, "py2")
+    tox_testenv_install_deps(action=action, venv=venv)
+    assert len(pcalls) == 1
+    call = pcalls[0]
+    assert "conda" in call.args[0]
+    assert "install" == call.args[1]
+    assert not isinstance(call.stdout, io.IOBase)
+
+
+def mock_open_to_string(mock):
+    return "".join(call.args[0] for call in mock().write.call_args_list)
