@@ -3,10 +3,13 @@ import os
 import re
 import shutil
 import subprocess
+import tempfile
+from pathlib import Path
 
 import pluggy
 import py.path
 import tox
+from ruamel.yaml import YAML
 from tox.config import DepConfig, DepOption, TestenvConfig
 from tox.venv import VirtualEnv
 
@@ -102,10 +105,12 @@ def tox_configure(config):
         envconfig.setenv["CONDA_DEFAULT_ENV"] = envconfig.setenv["TOX_ENV_DIR"]
 
         conda_deps = [DepConfig(str(name)) for name in envconfig.conda_deps]
-        # Add the conda-spec.txt file to the end of the conda deps b/c any deps
-        # after --file option(s) are ignored
+        # Append filenames of additional dependency sources. tox will automatically hash
+        # their contents to detect changes.
         if envconfig.conda_spec is not None:
-            conda_deps.append(DepConfig("--file={}".format(envconfig.conda_spec)))
+            conda_deps.append(DepConfig(envconfig.conda_spec))
+        if envconfig.conda_env is not None:
+            conda_deps.append(DepConfig(envconfig.conda_env))
         envconfig.deps.extend(conda_deps)
 
         envconfig.conda_exe = conda_exe
@@ -140,6 +145,11 @@ def _exit_on_missing_conda():
     raise SystemExit(0)
 
 
+def _run_conda_process(args, venv, action, cwd):
+    redirect = tox.reporter.verbosity() < tox.reporter.Verbosity.DEBUG
+    venv._pcall(args, venv=False, action=action, cwd=cwd, redirect=redirect)
+
+
 @hookimpl
 def tox_testenv_create(venv, action):
     tox.venv.cleanup_for_venv(venv)
@@ -153,15 +163,24 @@ def tox_testenv_create(venv, action):
         # conda env create does not have a --channel argument nor does it take
         # dependencies specifications (e.g., python=3.8). These must all be specified
         # in the conda-env.yml file
-        args = [
-            venv.envconfig.conda_exe,
-            "env",
-            "create",
-            "-p",
-            envdir,
-            "--file",
-            venv.envconfig.conda_env,
-        ]
+        yaml = YAML()
+        env_file = yaml.load(Path(venv.envconfig.conda_env))
+        env_file["dependencies"].append(python)
+
+        with tempfile.NamedTemporaryFile(suffix=".yaml") as tmp_env:
+            yaml.dump(env_file, tmp_env)
+
+            args = [
+                venv.envconfig.conda_exe,
+                "env",
+                "create",
+                "-p",
+                envdir,
+                "--file",
+                tmp_env.name,
+            ]
+
+            _run_conda_process(args, venv, action, basepath)
     else:
         args = [venv.envconfig.conda_exe, "create", "--yes", "-p", envdir]
         for channel in venv.envconfig.conda_channels:
@@ -172,7 +191,7 @@ def tox_testenv_create(venv, action):
 
         args += [python]
 
-    venv._pcall(args, venv=False, action=action, cwd=basepath)
+        _run_conda_process(args, venv, action, basepath)
 
     venv.envconfig.conda_python = python
 
@@ -213,7 +232,8 @@ def install_conda_deps(venv, action, basepath, envdir):
     # with the installed python version, installation will fail (which is what
     # we want).
     args += [venv.envconfig.conda_python] + conda_deps
-    venv._pcall(args, venv=False, action=action, cwd=basepath)
+
+    _run_conda_process(args, venv, action, basepath)
 
 
 @hookimpl
@@ -227,10 +247,14 @@ def tox_testenv_install_deps(venv, action):
 
     if num_conda_deps > 0:
         install_conda_deps(venv, action, venv.path.dirpath(), venv.envconfig.envdir)
-        # Account for the fact that we added the conda_deps to the deps list in
-        # tox_configure (see comment there for rationale). We don't want them
-        # to be present when we call pip install.
-        venv.envconfig.deps = venv.envconfig.deps[: -1 * num_conda_deps]
+
+    # Account for the fact that we added the conda_deps to the deps list in
+    # tox_configure (see comment there for rationale). We don't want them
+    # to be present when we call pip install.
+    if venv.envconfig.conda_env is not None:
+        num_conda_deps += 1
+    if num_conda_deps > 0:
+        venv.envconfig.deps = venv.envconfig.deps[:-num_conda_deps]
 
     with activate_env(venv, action):
         tox.venv.tox_testenv_install_deps(venv=venv, action=action)
